Module error

Module error 

Error type shared by the serializer and deserializer. Error type used throughout serde-structprop.

Error implements both serde::de::Error and serde::ser::Error so that it can be used as the single error type for all (de)serialization operations.

Enums

Error
All errors that can arise during serialization or deserialization of a structprop document.

Type Aliases

Result
Convenience alias for std::result::Result<T, Error>.