Module parse

Module parse 

Parser that converts a token stream into a parse::Value tree. Parser for the structprop format.

This module contains the Value type that represents a parsed structprop document and the parse() function that converts a raw &str into a Value::Object tree.

Grammar (informal)

document   = assignment*
assignment = TERM '=' value
           | TERM '{' assignment* '}'
value      = TERM
           | '{' (TERM | '{' assignment* '}')* '}'

Enums

Value
A node in the structprop value tree produced by parse().

Functions

parse
Parse a structprop document from input and return the top-level Value::Object.